thorn.funtests.suite — Thorn 1.3.0 documentation

# thorn.funtests.suite

- thorn.funtests.suite
  - Instructions

## thorn.funtests.suite

Functional test suite.

### Instructions

1. Start the celery worker:

    $ celery -A thorn.funtests worker -l info -P eventlet -c 1000

1. Start the development web server:

   >     $ (cd testproj; python manage.py runserver)

2. Then execute the functional test suite:

   >     $ celery -A thorn.funtests cyanide

For a list of tests that you can select see:

    $ celery -A thorn.funtests cyanide -l

class `thorn.funtests.suite.` `Default`(app, block_timeout=1800, no_color=False, stdout=None, stderr=None)
  `endpoints`()
  `hundred_subscribers`(event=u'article.created')
  `sender_mismatch_does_not_dispatch`(event=u'article.changed')
  `subscribe_to_article_changed`(event=u'article.changed')
  `subscribe_to_article_created`(event=u'article.created')
  `subscribe_to_article_published`(event=u'article.published')
  `subscribe_to_article_removed`(event=u'article.removed')
  `subscribe_to_tag_added`(event=u'article.tag_added')
  `subscribe_to_tag_all_cleared`(event=u'article.tag_all_cleared')
  `subscribe_to_tag_removed`(event=u'article.tag_removed')
  `subscriber_callback_setting`(event=u'article.changed')
  `subscriber_setting`(event=u'article.changed')
  `unsubscribe_does_not_dispatch`(event=u'article.created')

`thorn.funtests.suite.` `callback_subscribers`(event, sender=None, **kwargs)